# __version__ = "0.0.58" # 周期增加月份支持
# __version__ = "0.0.59" # 增加Indicator
# __version__ = "0.0.60" # 增加datatimetype
# __version__ = "0.0.61" # query_hisotry_n由decimal改为返回float
__version__ = "0.0.70" # DataTimeType -> Timing